const marked = import('marked')

import type { DateRange } from '@goldenwere/mackenzii-types'

/**
 * Converts a date object/string/number into a formatted date string
 * @param date the date to format
 * @returns the date formatted into locale string (or the original date if a string)
 */
export const getFormattedDate = (date: DateRange | string | number): string => {
  const { from, to } = date as DateRange
  if (!!from || !!to) {
    return `${getFormattedDate(from)} - ${getFormattedDate(to)}`
  } else {
    const num = Number(date)

    if (isNaN(+num)) {
      return date as string
    }

    return new Date(num).toLocaleDateString()
  }
}

/**
 * Parses the given markdown to HTML
 * @param md the markdown string to parse
 * @returns the parsed HTML string
 */
export const parseMarkdown = async (md: string) => {
  return (await marked).parse(md)
}
